#!/usr/bin/env python
###
#    
#    Copyright (C) 2007  Mola Pahnadayan
#
#    This program is free software; you can redistribute it and/or modify
#    it under the terms of the GNU General Public License as published by
#    the Free Software Foundation; either version 2 of the License, or
#    (at your option) any later version.
#
#    This program is distributed in the hope that it will be useful,
#    but WITHOUT ANY WARRANTY; without even the implied warranty of
#    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#    GNU General Public License for more details.
#
#    You should have received a copy of the GNU General Public License
#    along with this program; if not, write to the Free Software
#    Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
##

holiday = { 1386:[[1,1],[1,2],[1,3],[1,4],[1,12],[1,13],[1,17],
                  [2,14],[2,28],[3,14],[3,15],[3,28],[5,6],[5,20],[6,7],
                  [7,11],[7,21],[8,15],[9,30],[10,8],[10,28],[10,29],
                  [11,22],[12,9],[12,17],[12,18],[12,29]],
	    1387:[[1,1],[1,2],[1,3],[1,4],[1,12],[1,13],[3,14],[3,15],[3,18],[4,26],[5,9],[5,27],
                  [7,1],[7,10],[8,4],[9,19],[9,27],[10,17],[10,18],
                  [11,22],[11,28],[12,6],[12,8],[12,25],[12,29]],
		1388:[[1,1],[1,2],[1,3],[1,4],[1,12],[1,13],[3,7],[3,14],[3,15],[4,15],[4,29],[5,16],
                  [6,20],[6,29],[7,22],[9,7],[9,15],[10,5],[10,6],
                  [11,16],[11,22],[11,24],[11,26],[12,13],[12,29]] }
